@@ -10,6 +10,7 @@
 //! constraints.
 use crate::controldir::ControlDir;
 use crate::error::Error;
+use crate::foreign::VcsType;
 use crate::lock::Lock;
 use crate::repository::Repository;
 use crate::revisionid::RevisionId;
@@ -36,6 +37,10 @@ pub trait Branch: ToPyObject + Send {
         Python::with_gil(|py| BranchFormat(self.to_object(py).getattr(py, "_format").unwrap()))
     }
 
+    fn vcs_type(&self) -> VcsType {
+        self.repository().vcs_type()
+    }
+
     fn revno(&self) -> u32 {
         Python::with_gil(|py| {
             self.to_object(py)
@@ -54,6 +59,14 @@ pub trait Branch: ToPyObject + Send {
         })
     }
 
+    fn lock_write(&self) -> Result<Lock, crate::error::Error> {
+        Python::with_gil(|py| {
+            Ok(Lock::from(
+                self.to_object(py).call_method0(py, "lock_write")?,
+            ))
+        })
+    }
+
     fn tags(&self) -> Result<crate::tags::Tags, crate::error::Error> {
         Python::with_gil(|py| {
             Ok(crate::tags::Tags::from(
@@ -364,3 +377,14 @@ pub fn open_containing(url: &url::Url) -> Result<(Box<dyn Branch>, String), Erro
         ))
     })
 }
+
+pub fn open_from_transport(
+    transport: &crate::transport::Transport,
+) -> Result<Box<dyn Branch>, Error> {
+    Python::with_gil(|py| {
+        let m = py.import_bound("breezy.branch").unwrap();
+        let c = m.getattr("Branch").unwrap();
+        let r = c.call_method1("open_from_transport", (transport.to_object(py),))?;
+        Ok(Box::new(RegularBranch(r.to_object(py))) as Box<dyn Branch>)
+    })
+}
