@@ -5,6 +5,7 @@
 //! It mostly wraps the `breezy.plugins.debian` module from the Breezy VCS.
 pub mod apt;
 pub mod debcommit;
+pub mod directory;
 pub mod error;
 pub mod merge_upstream;
 pub mod release;
@@ -79,6 +80,19 @@ pub enum VersionKind {
     Release,
 }
 
+impl std::str::FromStr for VersionKind {
+    type Err = String;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        match s {
+            "auto" => Ok(VersionKind::Auto),
+            "snapshot" => Ok(VersionKind::Snapshot),
+            "release" => Ok(VersionKind::Release),
+            _ => Err(format!("Invalid version kind: {}", s)),
+        }
+    }
+}
+
 impl ToPyObject for VersionKind {
     fn to_object(&self, py: Python) -> PyObject {
         match self {
@@ -89,6 +103,16 @@ impl ToPyObject for VersionKind {
     }
 }
 
+impl std::fmt::Display for VersionKind {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        match self {
+            VersionKind::Auto => write!(f, "auto"),
+            VersionKind::Snapshot => write!(f, "snapshot"),
+            VersionKind::Release => write!(f, "release"),
+        }
+    }
+}
+
 impl FromPyObject<'_> for VersionKind {
     fn extract_bound(ob: &Bound<PyAny>) -> PyResult<Self> {
         let kind = ob.extract::<String>()?;
