@@ -52,6 +52,8 @@ import_exception!(breezy.plugins.gitlab.forge, ForkingDisabled);
 import_exception!(breezy.plugins.gitlab.forge, GitLabConflict);
 import_exception!(breezy.plugins.gitlab.forge, ProjectCreationTimeout);
 import_exception!(breezy.forge, SourceNotDerivedFromTarget);
+import_exception!(breezy.controldir, BranchReferenceLoop);
+import_exception!(breezy.errors, RedirectRequested);
 
 lazy_static::lazy_static! {
     // Only present in breezy << 4.0
@@ -134,6 +136,12 @@ pub enum Error {
     ProjectCreationTimeout(String, chrono::Duration),
     GitLabConflict(String),
     SourceNotDerivedFromTarget,
+    BranchReferenceLoop,
+    RedirectRequested {
+        source: url::Url,
+        target: url::Url,
+        is_permanent: bool,
+    },
 }
 
 impl From<url::ParseError> for Error {
@@ -274,6 +282,18 @@ impl std::fmt::Display for Error {
             }
             Self::GitLabConflict(p) => write!(f, "GitLab conflict: {}", p),
             Self::SourceNotDerivedFromTarget => write!(f, "Source not derived from target"),
+            Self::BranchReferenceLoop => write!(f, "Branch reference loop"),
+            Self::RedirectRequested {
+                source,
+                target,
+                is_permanent,
+            } => {
+                write!(
+                    f,
+                    "Redirect requested: {} -> {} (permanent: {})",
+                    source, target, is_permanent
+                )
+            }
         }
     }
 }
@@ -541,6 +561,24 @@ impl From<PyErr> for Error {
                 .unwrap_or(false)
             {
                 Error::ConnectionError(err.to_string())
+            } else if err.is_instance_of::<RedirectRequested>(py) {
+                Error::RedirectRequested {
+                    source: value
+                        .getattr("source")
+                        .unwrap()
+                        .extract::<String>()
+                        .unwrap()
+                        .parse()
+                        .unwrap(),
+                    target: value
+                        .getattr("target")
+                        .unwrap()
+                        .extract::<String>()
+                        .unwrap()
+                        .parse()
+                        .unwrap(),
+                    is_permanent: value.getattr("is_permanent").unwrap().extract().unwrap(),
+                }
             // Intentionally sorted below the more specific errors
             } else if err.is_instance_of::<InvalidHttpResponse>(py) {
                 Error::InvalidHttpResponse(
@@ -551,6 +589,8 @@ impl From<PyErr> for Error {
                 )
             } else if err.is_instance_of::<TransportError>(py) {
                 Error::TransportError(value.getattr("msg").unwrap().extract().unwrap())
+            } else if err.is_instance_of::<BranchReferenceLoop>(py) {
+                Error::BranchReferenceLoop
             } else {
                 Self::Other(err)
             }
@@ -667,6 +707,12 @@ impl From<Error> for PyErr {
             Error::ProjectCreationTimeout(p, t) => ProjectCreationTimeout::new_err((p, t)),
             Error::GitLabConflict(p) => GitLabConflict::new_err((p,)),
             Error::SourceNotDerivedFromTarget => SourceNotDerivedFromTarget::new_err(()),
+            Error::BranchReferenceLoop => BranchReferenceLoop::new_err(()),
+            Error::RedirectRequested {
+                source,
+                target,
+                is_permanent,
+            } => RedirectRequested::new_err((source.to_string(), target.to_string(), is_permanent)),
         }
     }
 }
@@ -1202,3 +1248,17 @@ fn test_already_branch() {
         assert!(p.is_instance_of::<AlreadyBranchError>(py), "{}", p);
     });
 }
+
+#[test]
+fn test_redirect_requested() {
+    let e = Error::RedirectRequested {
+        source: "http://example.com".parse().unwrap(),
+        target: "http://example.com".parse().unwrap(),
+        is_permanent: true,
+    };
+    let p: PyErr = e.into();
+    // Verify that p is an instance of RedirectRequested
+    Python::with_gil(|py| {
+        assert!(p.is_instance_of::<RedirectRequested>(py), "{}", p);
+    });
+}
