@@ -246,6 +246,24 @@ impl MergeProposal {
                 .map_err(|e| e.into())
         })
     }
+
+    pub fn get_merged_by(&self) -> Result<Option<String>, crate::error::Error> {
+        Python::with_gil(|py| {
+            let merged_by = self.0.call_method0(py, "get_merged_by")?;
+            merged_by.extract(py).map_err(|e| e.into())
+        })
+    }
+
+    pub fn get_merged_at(
+        &self,
+    ) -> Result<Option<chrono::DateTime<chrono::Utc>>, crate::error::Error> {
+        Python::with_gil(|py| {
+            let merged_at = self.0.call_method0(py, "get_merged_at")?;
+            merged_at
+                .extract::<Option<chrono::DateTime<chrono::Utc>>>(py)
+                .map_err(|e| e.into())
+        })
+    }
 }
 
 #[pyclass]
@@ -542,6 +560,30 @@ impl Forge {
             url.parse::<url::Url>().unwrap()
         })
     }
+
+    pub fn get_user_url(&self, user: &str) -> Result<url::Url, crate::error::Error> {
+        Python::with_gil(|py| {
+            let url = self
+                .to_object(py)
+                .call_method1(py, "get_user_url", (user,))
+                .unwrap()
+                .extract::<String>(py)
+                .unwrap();
+            Ok(url.parse::<url::Url>().unwrap())
+        })
+    }
+
+    pub fn get_current_user(&self) -> Result<Option<String>, crate::error::Error> {
+        Python::with_gil(|py| {
+            let user = self
+                .to_object(py)
+                .call_method0(py, "get_current_user")
+                .unwrap()
+                .extract::<Option<String>>(py)
+                .unwrap();
+            Ok(user)
+        })
+    }
 }
 
 impl std::fmt::Debug for Forge {
@@ -581,6 +623,14 @@ pub fn get_forge(branch: &dyn Branch) -> Result<Forge, Error> {
     })
 }
 
+pub fn get_forge_by_hostname(hostname: &str) -> Result<Forge, Error> {
+    Python::with_gil(|py| {
+        let m = py.import_bound("breezy.forge").unwrap();
+        let forge = m.call_method1("get_forge_by_hostname", (hostname,))?;
+        Ok(Forge(forge.to_object(py)))
+    })
+}
+
 pub fn determine_title(description: &str) -> String {
     Python::with_gil(|py| {
         let m = py.import_bound("breezy.forge").unwrap();
