@@ -29,6 +29,7 @@ pub mod dirty_tracker;
 pub mod error;
 pub mod export;
 pub mod forge;
+pub mod foreign;
 pub mod fossil;
 pub mod git;
 pub mod github;
@@ -52,7 +53,6 @@ pub mod revisionid;
 pub mod status;
 pub mod subversion;
 pub mod tags;
-#[cfg(test)]
 pub mod testing;
 pub mod transform;
 pub mod transport;
