@@ -102,7 +102,7 @@ mod tests {
         let env = TestEnv::new();
         assert_eq!(env.home_dir, env.temp_dir.path().join("home"));
         assert_eq!(env.working_dir, env.temp_dir.path().join("test"));
-        assert_eq!(std::env::current_dir().unwrap(), env.working_dir);
+        assert_eq!(std::env::current_dir().unwrap(), env.working_dir.canonicalize().unwrap());
         assert_eq!(
             std::env::var("HOME").unwrap(),
             env.home_dir.to_str().unwrap()
@@ -117,9 +117,9 @@ mod tests {
             assert_eq!(
                 os.call_method0("getcwd")
                     .unwrap()
-                    .extract::<String>()
+                    .extract::<PathBuf>()
                     .unwrap(),
-                env.working_dir.to_str().unwrap()
+                env.working_dir.canonicalize().unwrap(),
             );
             assert_eq!(
                 os.call_method1("getenv", ("HOME",))
